/*
  Copyright 1995 The University of Rhode Island and The Massachusetts
  Institute of Technology

  Portions of this software were developed by the Graduate School of
  Oceanography (GSO) at the University of Rhode Island (URI) in collaboration
  with The Massachusetts Institute of Technology (MIT).

  Access and use of this software shall impose the following obligations and
  understandings on the user. The user is granted the right, without any fee
  or cost, to use, copy, modify, alter, enhance and distribute this software,
  and any derivative works thereof, and its supporting documentation for any
  purpose whatsoever, provided that this entire notice appears in all copies
  of the software, derivative works and supporting documentation.  Further,
  the user agrees to credit URI/MIT in any publications that result from the
  use of this software or in any product that includes this software. The
  names URI, MIT and/or GSO, however, may not be used in any advertising or
  publicity to endorse or promote any products or commercial entity unless
  specific written permission is obtained from URI/MIT. The user also
  understands that URI/MIT is not obligated to provide the user with any
  support, consulting, training or assistance of any kind with regard to the
  use, operation and performance of this software nor to provide the user
  with any updates, revisions, new versions or "bug fixes".

  THIS SOFTWARE IS PROVIDED BY URI/MIT "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
  EVENT SHALL URI/MIT BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
  DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
  PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTUOUS
  ACTION, ARISING OUT OF OR IN CONNECTION WITH THE ACCESS, USE OR PERFORMANCE
  OF THIS SOFTWARE.
*/

// This is the main CGI program which extracts DDS class descriptors from a
// netCDF data file. In addition, the descriptors from an external file (if 
// exist, with the same name as the netCDF file and extension of .dds)  
// are extracted and added to the in-memory DDS table before it is sent 
// over the network to the client side. 
//
// ReZa 10/20/94

// $Log: nc_dds.cc,v $
// Revision 1.15  1999/05/08 00:38:20  jimg
// Fixes for the String --> string changes
//
// Revision 1.14  1999/05/07 23:45:33  jimg
// String --> string fixes
//
// Revision 1.13  1998/03/20 00:31:06  jimg
// Changed calls to the set_mime_*() to match the new parameters
//
// Revision 1.12  1997/12/30 23:53:31  jimg
// Removed useless includes.
//
// Revision 1.11  1997/12/30 22:48:40  jimg
// Fixed an error message that claimed this was the nc_dods filter.
//
// Revision 1.10  1997/08/27 00:11:00  jimg
// Changed main() to use the new DODSFilter class.
//
// Revision 1.9  1997/03/10 16:24:20  reza
// Added error object and upgraded to DODS core release 2.12.
//
// Revision 1.8  1996/11/01 00:19:00  jimg
// Added some limited error returns.
//
// Revision 1.7  1996/09/17 17:07:03  jimg
// Merge the release-2-0 tagged files (which were off on a branch) back into
// the trunk revision.
//
// Revision 1.6.4.2  1996/07/10 21:44:41  jimg
// Changes for version 2.06. These fixed lingering problems from the migration
// from version 1.x to version 2.x.
// Removed some (but not all) warning generated with gcc's -Wall option.
//
// Revision 1.6.4.1  1996/06/25 22:05:04  jimg
// Version 2.0 from Reza.
//
// Revision 1.6  1995/07/09  21:33:58  jimg
// Added copyright notice.
//
// Revision 1.5  1995/06/27  21:07:30  jimg
// Fixed up the error reporting. Added/corrected some comments.
//
// Revision 1.4  1995/06/23  15:33:25  jimg
// Modified these so that they are simple UNIX filters which write a MIME
// docement onto standard output.
//
// Revision 1.3  1995/03/16  16:56:52  reza
// Updated for the new DAP. All the read_val mfunc. and their memory management
// are now moved to their parent class.
// Data transfers are now in binary while DAS and DDS are still sent in ASCII.
//
// Revision 1.2  1994/10/28  15:12:15  reza
// Added the comments
//
// Revision 1.1  1994/10/28  14:34:02  reza
// First version
//

static char rcsid[]={"$Id: nc_dds.cc,v 1.15 1999/05/08 00:38:20 jimg Exp $"};

#include <iostream>
#include <string>

#include "DDS.h"
#include "cgi_util.h"
#include "DODSFilter.h"

extern bool read_descriptors(DDS &dds, const string &filename, string *error);

int 
main(int argc, char *argv[])
{
    DDS dds;
    DODSFilter df(argc, argv);

    if (!df.OK()) {
	df.print_usage();
	return 1;
    }

    if (df.version()) {
	df.send_version_info();
	return 0;
    }

    // Read the netCDF file dataset descriptor in memory
    try {
	string errMsg;
	if (!read_descriptors(dds, df.get_dataset_name(), &errMsg)) {
	    ErrMsgT("nc_dds: could not read the DDS information");
	    //client error message
	    Error e(unknown_error, errMsg);
	    set_mime_text(cout, dods_error, df.get_cgi_version());
	    e.print(cout);
	    return 1;
	}

	if (!df.read_ancillary_dds(dds))
	    return 1;

	if (!df.send_dds(dds, true))
	    return 1;
    }
    catch (Error &e) {
	set_mime_text(cout, dods_error, df.get_cgi_version());
	e.print(cout);
	return 1;
    }

    return 0;
}
